@@ -1,5 +1,5 @@
 """Top-level package for CellarTracker."""
 
 __author__ = """Mathieu Rul"""
-__email__ = 'mathieu.rul@gmail.com'
-__version__ = '1.0.0'
+__email__ = 'mathroule@gmail.com'
+__version__ = '1.1.0'
